###############################################################################
#
#    External Job, for Odoo
#    Copyright © 2018, 2022-2025 XCG Consulting (https://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################
from io import BytesIO

from odoo.tests import TransactionCase
from requests import PreparedRequest, Response, Session


class ExtrunnerTest(TransactionCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.server_base_url = "http://BASE-URL-1"
        cls.extrunner_request_status_code_auth = 200
        cls.extrunner_request_content = b""
        cls.extrunner_request_status_code = 200

    def setUp(self):
        super().setUp()
        self.user_demo = self.env.ref("base.user_demo")
        self.user_admin = self.env.ref("base.user_admin")
        self.server = (
            self.env["external_job.extrunner_server"]
            .with_user(self.user_admin)
            .create(
                {
                    "base_url": self.__class__.server_base_url,
                    "user_login": "secret1",
                    "user_password": "secret2",
                }
            )
        )
        self.job_definition = (
            self.env["external_job.job_definition"]
            .with_user(self.user_admin)
            .create(
                {
                    "extrunner_server_id": self.server.id,
                    "env_var_ids": [
                        (0, 0, {"key": "STATIC-1", "value": "1"}),
                        (
                            0,
                            0,
                            {"key": "DYN-1", "value": "%(job_definition.name)s x"},
                        ),
                    ],
                    "job_type": "extrunner",
                    "name": "DEF-1",
                    "output_filename_base": "test.csv",
                }
            )
        )

    @classmethod
    def _request_handler(cls, s: Session, r: PreparedRequest, /, **kw):
        # Handle calls to extrunner auth and run
        if r.url.startswith(f"{cls.server_base_url}/auth/login".lower()):
            r = Response()
            r.status_code = cls.extrunner_request_status_code_auth
            r.raw = BytesIO(b'{"id_token": "foo-bar-melt-down"}')
            return r
        if r.url.startswith(f"{cls.server_base_url}/run/".lower()):
            r = Response()
            r.status_code = cls.extrunner_request_status_code
            r.raw = BytesIO(cls.extrunner_request_content)
            return r
        return super()._request_handler(s, r, **kw)  # pragma: no cover
