###############################################################################
#
#    External Jobs, for Odoo
#    Copyright © 2022-2025 XCG Consulting (https://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################
from odoo.exceptions import AccessError  # type: ignore[untyped-import]
from odoo.tools import mute_logger

from ._common import ExtrunnerTest


class Test(ExtrunnerTest):
    """Tests for external_job.job_log"""

    def test_name_get(self):
        """Test that the name_get does not crash"""
        job_log = self.job_definition.with_user(self.user_demo).run_job()
        self.assertEqual(self.job_definition.job_count, 1)
        result = job_log.display_name
        # assert depends on installed languages so just check length
        self.assertGreater(len(result), 0)

    def test_job_log_access(self):
        """Tests than only creator of the job can access a job log."""
        job_log = self.job_definition.with_user(self.user_admin).run_job()
        self.assertNotEqual(job_log.create_uid.id, self.user_demo.id)
        logs = self.env["external_job.job_log"].search([])
        self.assertEqual(len(logs), 1)
        logs = self.env["external_job.job_log"].with_user(self.user_demo).search([])
        self.assertEqual(len(logs), 0)
        with (
            mute_logger("odoo.addons.base.models.ir_rule"),
            self.assertRaises(AccessError),
        ):
            self.env["external_job.job_log"].with_user(self.user_demo).browse(  # noqa: B018 # pylint: disable=expression-not-assigned
                job_log.id
            ).create_uid
